@@ -1,11 +1,14 @@
 import pyfmtools as pyfm
+import random
 import sys
 
+
 r=3
 n=3
 env = pyfm.fm_init( n)
 pyfm.isTest = True
 
+
 A = pyfm.ShowCoalitions( env)
 print( "Fuzzy measure wrt n=3 criteria has ",env.m," parameters ordered like this (binary order)")
 print( A)
@@ -162,16 +165,6 @@ print( "src: ", src)
 print( "kint: ", kint)
 print( "dest: ", dest)
 
-# Test wrapper for:
-#    void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)
-src = [0.0340916, 0.01109779, 0.07918582,0.7,1]
-kint = 1
-dest, VVC = pyfm.ExpandKinteractive2Bit_m(src, env, kint)
-print( "src: ", src)
-print( "kint: ", kint)
-print( "dest: ", dest)
-print( "VVC: ", VVC)
-
 # Test wrapper for:
 #    void py_Shapley(double* v, double* out_x, struct fm_env* env)
 # pyfm.Shapley(v, env)
@@ -317,7 +310,7 @@ print( "v: ", v)
 datanum = 10
 additive = 2
 K = 0.5
-maxiters = [100]
+maxiters = 100
 v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
@@ -332,7 +325,9 @@ datanum = 10
 additive = 2
 K = 0.5
 submod = 1
-v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env,  K, submod, dataset = None)
+dataset = [0] * datanum * ( env.n + 1)
+for i in range( 0, len( dataset)): dataset[i] = random.random()
+v = pyfm.FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env,  K, submod, dataset)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "submod: ", submod)
